#
# spec file for package at-spi2-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# TODO: Double check whether we really need bundled fonts such as:
#         /usr/share/doc/libatspi/RedHatText-Regular.woff2
#         /usr/share/doc/libatspi/SourceCodePro-It.ttf.woff
#
%define atspiconfdir %{?_distconfdir}%{!?_distconfdir:%{_sysconfdir}}

Name:           at-spi2-core
Version:        2.54.0
Release:        1.1
Summary:        Assistive Technology Service Provider Interface - D-Bus based implementation
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://www.gnome.org/
Source0:        https://download.gnome.org/sources/at-spi2-core/2.54/%{name}-%{version}.tar.xz
Source99:       baselibs.conf

BuildRequires:  fdupes
BuildRequires:  meson >= 0.63.0
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  pkgconfig(dbus-1) >= 1.5
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.28.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.62.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.0.0
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xtst)
# dbus-daemon is needed to have this work fine
Requires:       (dbus-1 or dbus-broker)
Provides:       at-spi2-atk-gtk2 = %{version}
Obsoletes:      at-spi2-atk-gtk2 < %{version}
Provides:       at-spi2-atk-common = %{version}
Obsoletes:      at-spi2-atk-common < %{version}
# xprop is needed when using XWayland
Requires:       (xprop if xwayland)

%description
AT-SPI is a general interface for applications to make use of the
accessibility toolkit. This version is based on dbus.

This package contains the AT-SPI registry daemon. It provides a
mechanism for all assistive technologies to discover and interact
with applications running on the desktop.

%package -n libatspi0
Summary:        Assistive Technology Service Provider Interface
Group:          System/Libraries

%description -n libatspi0
AT-SPI is a general interface for applications to make use of the
accessibility toolkit. This version is based on dbus.

%package -n typelib-1_0-Atspi-2_0
Summary:        Introspection bindings for the Assistive Technology Service Provider Interface
Group:          System/Libraries

%description -n typelib-1_0-Atspi-2_0
AT-SPI is a general interface for applications to make use of the
accessibility toolkit. This version is based on dbus.

This package provides the GObject Introspection bindings for the
libatspi library.

%package devel
Summary:        Development files for the Assistive Technology Service Provider Interface
Group:          Development/Libraries/GNOME
Requires:       at-spi2-core = %{version}
Requires:       libatk-1_0-0 = %{version}
Requires:       libatk-bridge-2_0-0 = %{version}
Requires:       libatspi0 = %{version}
Requires:       typelib-1_0-Atk-1_0 = %{version}
Requires:       typelib-1_0-Atspi-2_0 = %{version}
Provides:       at-spi2-atk-devel = %{version}
Obsoletes:      at-spi2-atk-devel < %{version}
Provides:       atk-devel = %{version}
Obsoletes:      atk-devel < %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n libatk-1_0-0
Summary:        An Accessibility Toolkit
Group:          System/Libraries
Provides:       atk = %{version}
Obsoletes:      atk < %{version}

%description -n libatk-1_0-0
The ATK library provides a set of accessibility interfaces. By
supporting the ATK interfaces, an application or toolkit can be used
with screen readers, magnifiers, and alternate input devices.

%package -n typelib-1_0-Atk-1_0
Summary:        Introspection bindings for the ATK accessibility toolkit
Group:          System/Libraries

%description -n typelib-1_0-Atk-1_0
The ATK library provides a set of accessibility interfaces. By
supporting the ATK interfaces, an application or toolkit can be used
with screen readers, magnifiers, and alternate input devices.

This package provides the GObject Introspection bindings for ATK.

%package -n libatk-bridge-2_0-0
Summary:        ATK/D-Bus bridging library
Group:          System/Libraries

%description -n libatk-bridge-2_0-0
AT-SPI is a general interface for applications to make use of the
accessibility toolkit. This version is based on dbus.

The package contains a ATK/D-Bus bridge library.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	--libexecdir="%{_libexecdir}/at-spi2" \
	-Ddbus_broker=/usr/bin/dbus-broker-launch \
	-Ddefault_bus=dbus-broker \
	-Ddocs=true \
	-Dintrospection=enabled \
	-Dx11=enabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}
# Move autostart file to /usr/etc
mkdir -p %{buildroot}%{atspiconfdir}/xdg/autostart
mkdir -p %{buildroot}%{atspiconfdir}/xdg/Xwayland-session.d
%if 0%{defined _distconfdir}
mv %{buildroot}%{_sysconfdir}/xdg/autostart/* %{buildroot}%{_distconfdir}/xdg/autostart/
mv %{buildroot}%{_sysconfdir}/xdg/Xwayland-session.d/* %{buildroot}%{_distconfdir}/xdg/Xwayland-session.d/
%endif

%ldconfig_scriptlets -n libatspi0
%ldconfig_scriptlets -n libatk-1_0-0
%ldconfig_scriptlets -n libatk-bridge-2_0-0

%files
%license COPYING
%{_libexecdir}/at-spi2/
%dir %{atspiconfdir}/xdg/Xwayland-session.d
%{atspiconfdir}/xdg/Xwayland-session.d/00-at-spi
%{atspiconfdir}/xdg/autostart/at-spi-dbus-bus.desktop
%{_userunitdir}/at-spi-dbus-bus.service
%dir %{_datadir}/dbus-1/accessibility-services/
%{_datadir}/dbus-1/accessibility-services/org.a11y.atspi.Registry.service
%{_datadir}/dbus-1/services/org.a11y.Bus.service
%dir %{_datadir}/defaults
%{_datadir}/defaults/at-spi2/
%dir %{_libdir}/gnome-settings-daemon-3.0
%dir %{_libdir}/gnome-settings-daemon-3.0/gtk-modules
%{_libdir}/gnome-settings-daemon-3.0/gtk-modules/at-spi2-atk.desktop
%dir %{_libdir}/gtk-2.0
%dir %{_libdir}/gtk-2.0/modules
%{_libdir}/gtk-2.0/modules/libatk-bridge.so

%files -n libatspi0
%{_libdir}/libatspi.so.0*

%files -n libatk-1_0-0
%{_libdir}/libatk-1.0.so.0*

%files -n libatk-bridge-2_0-0
%{_libdir}/libatk-bridge-2.0.so.0*

%files -n typelib-1_0-Atspi-2_0
%{_libdir}/girepository-1.0/Atspi-2.0.typelib

%files -n typelib-1_0-Atk-1_0
%{_libdir}/girepository-1.0/Atk-1.0.typelib

%files devel
%doc NEWS README.md
%{_includedir}/at-spi-2.0/
%{_includedir}/at-spi2-atk/
%{_includedir}/atk-1.0/
%{_libdir}/libatspi.so
%{_libdir}/libatk-1.0.so
%{_libdir}/libatk-bridge-2.0.so
%{_libdir}/pkgconfig/atspi-2.pc
%{_libdir}/pkgconfig/atk-bridge-2.0.pc
%{_libdir}/pkgconfig/atk.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/doc/atk/
%doc %{_datadir}/doc/libatspi/

%files lang -f at-spi2-core.lang

%changelog
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.54.0:
  + Updated translations.
* Sat Aug 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.53.90:
  + Make ATSPI_ROLE_PUSH_BUTTON an enum value again.
  + atk: Align button role with AT-SPI one.
  + Fix warning when atspi_event_quit is called multiple times.
* Sun Mar 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.52.0:
  + tests: Fix missing declaration for getpid().
* Sun Mar 10 2024 Michael Gorse <mgorse@suse.com>
- Remove unused dependencies on libei and libxkbcommon-x11.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.51.91:
  + Back out code to generate mouse events on mutter. It had a
    couple of unwanted side effects. Also remove dependencies on
    libei and xkbcommon.
  + atk-adaptor: Fix collection role matching.
  + Have atspi_text_get_string_at_offset fall back to calling
    GetTextAtOffset if GetStringAtOffset is unimplemented.
  + Don't use g_assert in the unit tests.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.51.90:
  + Add an attribute-changed signal in atk, and update libatspi
    attribute cache.
  + Add GetTextSelection and SetTextSelection to Document
    interface.
  + Add atspi_device_generate_mouse_event, and implement for
    mutter.
  + Have atspi_device_add_key_grab return 0 if XIGrabKeycode fails.
  + xml: Add Embedded to the Socket interface.
  + Don't return uninitialized values if
    atspi_component_get_size/position fail.
- Add pkgconfig(libei-1.0) BuildRequires: new dependency.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.51.0:
  + atk-adaptor: Fix critical when no table cell array is returned.
  + accessible: Do not rename deprecated methods to the new names.
  + Add HelpText property and corresponding functions in atk and
    libatspi.
* Sun Jan 14 2024 Yifan Jiang <yfjiang@suse.com>
- Provide and obsolete more packages from old atk and at-spi2-atk:
  atk-devel, at-spi2-atk-devel and at-spi2-atk-common.
* Mon Sep 18 2023 Luciano Santos <luc14n0@opensuse.org>
- Adjust %%fdupes parameter value to %%{buildroot}%%{_datadir}, one of
  the parent directories of the former parameter, to symlink other
  duplicate files under the datadir.
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.50.0:
  + Fix at-spi2-atk test when running under a non-English locale.
* Mon Sep  4 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 2.49.91:
  + collection: Avoid locking up if an object has a very large
    child count.
  + Fix possible NULL pointer dereference when deregistering an
    event listener.
  + Various fixes for the new key grabbing API.
  + Don't wait for a reply when registering or deregistering
    keystroke listeners.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.49.90:
  + Fix a test failure/timeout.
  + Add atspi_get_version() to return the runtime version of the
    library.
  + Collection: fix match testing for attributes.
  + Fix a NULL pointer dereference when deregistering an event
    listener that doesn't include a detail.
  + Fix the documentation for interfaces in collection match rules.
  + Add an AtspiLive enum to specify the politeness level for live
    regions, and document that this should be used for Announcement
    signals. Also add a notification signal in atk to replace the
    announcement signal that lacks the politeness information.
  + Add an asynchronous version of atspi_generate_mouse_event.
* Mon Sep  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.4:
  + Add atspi_get_version() to return the runtime version of the
    AT-SPI library.
  + collection:
  - Fix match testing for attributes.
  - Avoid locking up if an object has a very large child count.
  + Fix possible NULL pointer dereference when deregistering an
    event listener.
  + Various fixes for the new key grabbing API.
* Thu Aug  3 2023 Yifan Jiang <yfjiang@suse.com>
- Support build environments like SLE 15 SP5 and Leap 15.5 which
  had %%{_distconfdir) not defined yet.
* Tue Jul 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.49.1:
  + TableCell.xml: Add Get{Column,Row}HeaderCells methods.
  + atspi_accessible_get_localized_role_name: Use internal names
    when possible.
  + Add a non-recursive function to clear a single object's cache.
  + Code clean-ups.
* Sun May 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.3:
  + Fix the build when dbus-broker is not set to be used by
    default.
  + Fix a couple of use after frees when finalizing devices.
  + atk-adaptor: Fix handling of sockets in impl_GetChildren.
* Thu May 11 2023 Michael Gorse <mgorse@suse.com>
- Update to version 2.48.2:
  + Fixed a regression in 2.48.1 where the bus launcher would fail
    if dbus-broker was configured at build time but not installed
    on the system.
* Thu May 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.1:
  + Fixes for atk-only builds under Windows.
  + meson: Avoid requiring libsystemd when configured to use
    dbus-daemon.
  + Fix crash when a bad index is passed to
    atspi_accessible_get_child_at_index.
  + Fix possible infinite recursion in
    atspi_accessible_clear_cache.
* Thu May  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add or dbus-broker to existing dbus-1 Requires: we already pass
  dbus_broker=/usr/bin/dbus-broker-launch and
  default_bus=dbus-broker to meson during build.
* Sun Mar 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.48.0:
  + Add a "atk-only" build option. This allows atk to be built
    without libdbus installed, but it does not build libatspi or
    the atk bridge.
  + Fix some typos in the documentation.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.47.90:
  + Downgrade meson requirement to 0.63.
  + at-spi-dbus-bus service: set stop timeout to 5s.
  + Fix possible crash in screen_reader_signal_watcher.
* Thu Feb 23 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.47.1:
  + The meson options -Dx11 and -Dintrospection are now implemented
    with meson features.
  + Use gi-docgen to generate documentation.
  + Register key grabs using the focused window, rather than the
    root window. This should prevent the window from losing focus
    when a key grab is used.
  + atk-adaptor: Handle sockets in GetChildren.
  + Improve documentation of the dbus interfaces.
  + Various code clean-ups. Some unused code has been removed.
- Change -Dx11=yes and -Dintrospection=yes to -Dx11=enabled and
  - Dintrospection=enabled, following upstreams changes to use meson
  features.
- Add pkgconfig(gi-docgen) and python3-Sphinx BuildRequires: new
  dependencies to build the documentation.
- Drop gtk-doc BuildRequires: no longer needed.
* Fri Oct 28 2022 Frederic Crozat <fcrozat@suse.com>
- Ensure xprop is required when xwayland is installed.
* Sat Sep 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.0:
  + Fix GetInterfaces documentation on org.a11y.atspi.Accessible
    interface.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add libatk-1_0-0 and libatk-bridge-2_0-0 to baselibs.conf, build
  32bit support.
* Sat Aug 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.91:
  + Send device event controller events using the same signature as
    other events.
  + Document the Accessible, Action, and Cache dbus interfaces.
  + Fix license of atspi-gmain.c.
- Add fdupes BuildRequires and macro, remove duplicate files.
- Provide and Obsolete atk from libatk sub-package.
* Wed Aug 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.90:
  + xml:
  - Add some documentation.
  - Fix event arguments.
  - Add some missing DeviceEventController methods.
  + Bind the AT-SPI bus to the graphical session.
  + Mark bus service as belonging to the session slice.
  + Add ATSPI_ROLE_PUSH_BUTTON_MENU.
  + Add an "announcement" event/signal to allow objects to send
    notifications.
  + Various code clean-ups and test improvements.
- Add pkgconfig(libxml-2.0) BuildRequires: New dependency.
- Add new sub-packages from the now included atk and at-spi2-atk
  packages: libatk-1_0-0, libatk-bridge-2_0-0 and
  typelib-1_0-Atk-1_0.
- Provide/Obsolete at-spi2-atk-gtk2 by the main package.
* Thu Apr 21 2022 Michael Gorse <mgorse@suse.com>
- Update to version 2.44.1:
  + Fix use after free when removing a hung process.
  + Fix the build with X11 disabled.
  + Fix crash when NULL is passed to some listener-related functions.
  + impl_deregister_keystroke_listener: fix memory leak on
    iteration error.
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.44.0:
  + Unlink the socket before binding when using dbus-broker. Fixes
    regression introduced in 2.43.92 where restarting the bus
    launcher would fail.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.43.92:
  + The AT-SPI bus now uses the user's XDG_RUNTIME_DIR for its
    socket. Fixes accessibility for Snap-confined applications.
  + Caps lock is now unlocked for key synthesis. Fixes cutting and
    pasting from brltty when caps lock is on.
  + Several fixes to the dbus specification.
  + Fix the build when x11 is disabled.
  + Fix several compiler warnings.
- Use ldconfig_scriptlets macro for post(un) handling.
- Move autostart .desktop and xwayland-session config to
  distconfdir.
* Wed Dec  8 2021 Michael Gorse <mgorse@suse.com>
- Configure to use dbus-broker when available.
- Add libsystemd to BuildRequires: needed for dbus-broker support.
* Sun Sep 19 2021 Michael Gorse <mgorse@suse.com>
- Update to version 2.42.0:
  + Set X root property when Xwayland starts on demand.
  + Several dbus introspection fixes.
* Fri Jul  9 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.40.3
  + Bugfix: Use abstract sockets if libdbus is older than 1.12.0
* Sun Jun  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.40.2:
  + README: Remove outdated links.
  + Key grab fixes for the new API.
  + registryd: Add a missing call to va_end.
* Sun May  2 2021 Michael Gorse <mgorse@suse.com>
- Update to version 2.40.1:
  + Fix double free when removing event listeners.
  + Fix numlock detection.
* Sat Mar 20 2021 Michael Gorse <mgorse@suse.com>
- Update to version 2.40.0:
  + No changes.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.39.91:
  + Fix a couple of memory leaks.
  + Remove const from AtspiDeviceListenerCB prototype.
* Tue Feb 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.39.90.1:
  + Fix a crash introduced in 2.39.90, along with a few warnings.
* Wed Feb 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.39.90:
  + Fix build with X11 disabled.
  + Various fixes for the new device API used for key monitoring
    and grabbing.
  + Fixed several memory leaks.
* Sun Jan 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.39.1:
  + Don't use gdbus-broker if not running under systemd.
  + Unref bus at the end of cleanup.
  + Fix XML interfaces.
  + Use unix sockets instead of abstract sockets.
  + Added a device API to replace the old API for capturing key
    grabs. This is needed for toolkits that do not report
    keystrokes to atk, such as gtk 4.
* Tue Sep 22 2020 dimstar@opensuse.org
- Update to version 2.38.0:
  + Updated translations.
* Tue Sep 22 2020 dimstar@opensuse.org
- Update to version 2.37.92:
  + Fix a possible memory leak if an event name cannot be parsed.
  + _atspi_dbus_set_interfaces: fix memory leak when called with an
    invalid DBus signature.
  + Fix a crash if an event listener is removed during an event
    callback.
* Tue Sep 22 2020 dimstar@opensuse.org
- Update to version 2.37.90:
  + Add a mode-changed signal to allow a screen reader to indicate
    that its mode has changed.
  + Fix use after free when a device listener is destroyed.
  + Meson: de-duplicate deps of 'Requires' in pkgconfig file.
  + FIx use after free when an event listener is destroyed.
  + Make at-spi-dbus-bus.desktop validate.
  + atspi_accessible_set_cache_mask: relax assert that was
    generating a warning and causing the function to fail in some
    cases.
  + Fixes for synthesizing keys.
  + Fix Qt annotations in DBus xml files.
  + Memory test: replace gedit with a light-weight test
    application.
  + dbtest: print to stdout instead of stderr.
  + Tests: make test a bit verbose.
  + Constants: fix typos in two _COUNT constants.
* Sat Sep 12 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 2.36.1:
  + meson: De-duplicate deps of 'Requires' in pkgconfig file
  + Make at-spi-dbus-bus.desktop Validat
  + Fix ucs2keysym line for Euro sign
  + Fix Qt annotations in DBus xml files
  + constants: Fix typos in two _COUNT constants
  + Fix a couple of memory leaks.
  + Fix use after free when a device listener is destroyed.
  + Fix use after free when an event listener is destroyed.
- Run spec-cleaner
  + Remove rpm groups
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.36.0:
  + No changes, stable version update only.
* Sat Feb 29 2020 mgorse@suse.com
- Update to version 2.35.92:
  + bus-launcher: make session management more robust
    (boo#1154582).
- Drop at-spi2-core-async-session-register.patch: Fixed upstream.
* Thu Feb 27 2020 Michael Gorse <mgorse@suse.com>
- Ad at-spi2-core-async-session-register.patch: make bus-launcher
  session registration more robust (boo#1154582).
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 2.35.1:
  + Fix source reproducibility.
  + Avoid depending on Meson 0.50.
  + Add ATSPI_ROLE_MARK and ATSPI_ROLE_SUGGESTION.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 2.34.0:
  + Fix a use after free when freeing an event.
  + Clean up handling of the X11 property specifying the bus
    address.
  + Update doap.
* Mon Sep  2 2019 mgorse@suse.com
- Update to version 2.33.92:
  + Now requires meson 0.50.0.
  + License is now LGPL-2.1+.
  + Meson: only link to libdl when it is necessary.
  + Update installation instructions.
  + Clarify atspi_editable_text_insert_text documentation.
  + Do not warn on no reply from pending get_items call.
  + Eliminate some superfluous runtime warnings.
- Require meson >= 0.50.0.
- Set license to LGPL-2.1-or-later.
* Fri Aug 30 2019 mgorse@suse.com
- Update to version 2.33.90:
  + Refactor the API for the screen reader to notify listeners
    of its status.
  + Add a sender to the AtspiEvent struct.
  + Add missing atspi_application_get_type prototype.
  + Support mutter remote desktop interface for synthesizing
    keyboard/mouse events (likely still needs work).
* Tue Jun 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.33.2:
  + Check WAYLAND_DISPLAY, rather than XDG_SESSION_TYPE, to avoid X
    connections. Fixes breakage if X is started with startx and
    XDG_SESSION_TYPE is unset.
  + X11: also try mod4 and mod5 to generate keysyms.
  + Add ATSPI_ROLE_CONTENT_DELETION and
    ATSPI_ROLE_CONTENT_INSERTION.
  + Check for dbus-daemon in /usr/lib (for Solaris).
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.32.1:
  + Fix meson build for meson 0.50.0 and newer.
- Drop at-spi2-core-meson-build-fix.patch: Fixed upstream.
* Tue Mar 12 2019 mgorse@suse.com
- Add at-spi2-core-meson-build-fix.patch: fix build for meson
  0.50.0 (glgo#GNOME/at-spi2-core!9).
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.32.0:
  + Stable release version bump.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.31.92:
  + Fix atspi_table_cell_get_(row_column)_headers.
  + Update documentation to indicate that extents are only
    meaningful when an object has both STATE_VISIBLE and
    STATE_SHOWING.
  + Use a consistent style for the meson options.
  + Fix a compiler warning on BSD.
  + Add ScrollSubstringTo and ScrollSubstringToPoint text
    interfaces.
- Enable gtk-docs BuildRequires and update options passed to meson.
- Drop unneeded and unused intltool BuildRequires.
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 2.31.2:
  + Add ScrollSubstringTo and ScrollSubstringToPoint text
    interfaces.
* Tue Mar  5 2019 bjorn.lie@gmail.com
- Update to version 2.31.1:
  + Bus launcher: fix an issue where the error wasn't cleared on
    failure.
  + Add support for locking/unlocking modifiers.
  + Update error log text for consistency.
  + Documentation clean-ups.
- Drop upstream fixed patches:
  + at-spi2-core-bus-launch-use__linux__.patch.
  + at-spi2-core-generate-pc.patch.
* Mon Mar  4 2019 mgorse@suse.com
- Update to version 2.30.1:
  + Fix atspi_table_cell_get_(row|column)_header_cells
    (bsc#1127792).
* Thu Oct  4 2018 bjorn.lie@gmail.com
- Add at-spi2-core-bus-launch-use__linux__.patch: bus-launch:
  use __linux__ over __linux.
- Add at-spi2-core-generate-pc.patch: meson: Generate a pkg-config
  file.
- Disable gtk-doc BuildRequires and pass enable_docs=false to
  meson. Temp workaround for buildfail when building docs with
  meson 0.48.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 2.30.0:
  + No changes, stable bump only.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 2.29.1:
  + Add dbus-broker support to bus launcher.
  + Add ScrollTo and ScrollToPoint component interfaces.
  + Do not use deprecated GSettings API.
  + Fix various compiler warnings and documentation annotations.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 2.28.0:
  + Support building a static library (bgo#793652).
  + Fix build on FreeBSD (bgo#791608).
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 2.27.92:
  + Dropped autotools support.
  + Documentation: Remove list association from
    ATSPI_ROLE_DESCRIPTION_{TERM,VALUE} (bgo#791021).
  + Fix a potential buffer overflow in at-spi-bus-launcher
    (bgo#791124).
  + Make the build reproducible (bgo#791167).
- Drop at-spi2-core-bgo791124-buffer-overflow.patch and
  at-spi2-core-bgo791167-reproducible-build.patch: fixed upstream.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec  4 2017 mgorse@suse.com
- Add at-spi2-core-bgo791124-buffer-overflow.patch: fix possible
  buffer overflow reading dbus address in at-spi-bus-launcher
  (boo#1073027, bgo#791124).
- Add at-spi2-core-bgo791167-reproducible-build.patch: use
  @basename@ in templates, rather than @filename@; fixes build
  reproducibility and multiarch conflict (bgo#791167).
* Fri Dec  1 2017 zaitor@opensuse.org
- Switch to using meson buildsystem:
  + Add meson and gtk-doc BuildRequires.
  + Use meson, meson_build and meson_install macros instead of
    autotools macros.
  + Drop update-desktop-files BuildRequires and stop using
    suse_update_desktop_file macro, no longer needed.
  + Modernize spec, use spec-cleaner.
* Wed Nov  1 2017 fezhang@suse.com
- Update to version 2.26.2:
  + dist po/meson.build (bgo#789666).
  + Generate correct sonname when building with meson.
* Wed Nov  1 2017 fezhang@suse.com
- Update to version 2.26.1:
  + Remove unused dependency on libxkbcommon.
  + Various meson build fixes.
  + Updated translations.
* Tue Oct  3 2017 jengelh@inai.de
- Update package summaries and old RPM macros.
* Mon Sep 11 2017 luc14n0@linuxmail.org
- Update to version 2.26.0:
  + m4/gettext.m4, m4/iconv.m4, m4/lib-ld.m4, m4/lib-link.m4,
    m4/lib-prefix.m4, m4/nls.m4, m4/po.m4 and m4/progtest.m4:
    Upgrade to gettext-0.19.8.1.
  + configure.ac (AM_GNU_GETTEXT_VERSION): Bump to 0.19.8.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 2.25.92:
  + configure.ac: make xkb optional, as intended.
  + Optionally read the bus adddress from the ATSPI_BUS_ADDRESS
    environment variable (bgo#787126).
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 2.25.91:
  + Meson build files should now be usable, with the exception of
    the dist target.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 2.25.90:
  + Fix a couple of introspection issues (bgo#784481).
  + atspi_get_a11_bus: don't leak the DBusConnection.
  + Meson fixes.
* Thu Jun 22 2017 dimstar@opensuse.org
- Update to version 2.25.4:
  + Fix gir generation with autotools (bgo#783994).
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 2.25.3:
  + Fix -Wmisleading-indentation warnings.
  + Fix memory leak of at-spi-bus-launcher.
  + Add error-message, error-for, details, and details-for relation
    types.
  + Poll direct dbus connections in the main loop--fixes processes
    being marked hung and the hung flag never being removed.
  + Add Meson build system.
  + Various build fixes.
- Add pkgconfig(xkbcommon-x11) BuildRequires: new dependency.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 2.25.2:
  + Attempt to fix an occasional crash when an application
    disappears (bgo#767074).
  + Add some missing roles to correspond with atk (description
    list, description term, description value, and footnote).
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 2.25.1:
  + No changes.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 2.24.1:
  + atspi_table_cell_get_position: Don't crash on error.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 2.24.0:
  + No changes.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 2.23.92:
  + Table cell API fixes (bgo#779835).
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 2.23.90:
  + Fix an occasional crash when an application is closed
    (bgo#767074).
* Tue Jan 17 2017 dimstar@opensuse.org
- Update to version 2.23.4:
  + Don't pull in X headers if x11 is disabled (bgo#773710).
  + at-spi-bus-launcher: session management fixes (bgo#774441).
  + events: add recently added page changed event (bgo#719898).
  + roles: EXTENDED roles are deprecated (bgo#720123).
* Mon Sep 26 2016 zaitor@opensuse.org
- Update to version 2.22.0:
  + at-spi-bus-launcher: Fix uninitialized variable.
  + Fix return value error in session_manager_connect (bgo#768881).
  + Updated translations.
* Wed Jul 27 2016 zaitor@opensuse.org
- Update to version 2.21.4:
  + Fixed a crash in atspi_accessible_clear_cache.
  + Fixed a crash caused by at-spi2-registryd dying.
  + Fixed some session management issues in at-spi-bus-launcher.
- Drop at-spi2-core-session-management.patch: Fixed upstream.
* Wed Jul 27 2016 zaitor@opensuse.org
- Update to version 2.21.2:
  + Allow building without Xtst, Xi with --disable-x11.
  + ref_accessible_desktop: don't unref reply until we're finished
    with it.
  + Updated translations.
* Wed Jul 27 2016 zaitor@opensuse.org
- Update to version 2.21.1:
  + Fix parsing of at-spi-bus-launcher command line arguments
    (bgo#765220).
  + Build clean-ups.
* Wed Jul 27 2016 mgorse@suse.com
- Update at-spi2-core-session-management.patch: fix uninitialized
  variable (bsc#984109).
* Thu Jul 14 2016 mgorse@suse.com
- Add at-spi2-core-session-management.patch: properly register
  at-spi-bus-launcher with gnome-session (bsc#984109).
* Sat May 28 2016 zaitor@opensuse.org
- Drop at-spi2-core-devel Obsolete: the devel package have not
  existed since 2009. At the same time, drop rpmlintrc, since it's
  not needed anymore.
- Pkgconfig'ify spec file BuildRequires:
  + Replace/Remove: glib2-devel, gobject-introspection-devel,
    xorg-x11-devel.
  + Add: pkgconfig(gio-2.0), pkgconfig(glib-2.0),
    pkgconfig(gobject-2.0), pkgconfig(gobject-introspection-1.0),
    pkgconfig(x11), pkgconfig(xtst), pkgconfig(xi).
* Mon May 23 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Sun May 22 2016 zaitor@opensuse.org
- Update to version 2.20.2:
  + Fixed an invalid memory access when fetching an accessible.
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop at-spi2-core-null-event-source.patch: fixed upstream.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 2.20.1:
  + registryd: avoid crashing with a NULL keystring (bgo#764688).
  + Plug a memory leak in AtspiEventListener (bgo#764688).
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 2.20.0:
  + No changes.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 2.19.92:
  + Support a stateless configuration by default (bgo#763540).
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 2.19.91:
  + Don't display warnings when connecting to an app that no longer
    exists.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 2.19.90:
  + Don't display warning if unable to connect when logged in via
    ssh (bgo#761600).
  + at-spi-bus-launcher: register with session manager
    (bgo#753931).
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 2.19.2:
  + Disable xevie by default--it probably doesn't do anything
    anyhow.
  + get_index_in_parent: Don't crash if parent is defunct.
  + Don't crash when trying to set an invalid state (bgo#757915).
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 2.19.1:
  + atspi_hyperlink_get_index_range: don't return random values if
    the call fails (bgo#755727).
  + Fixed some atspi_text_ functions (bgo#755731).
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 2.18.3:
  + get_index_in_parent: Don't crash if the parent is defunct.
* Sun Nov  8 2015 badshah400@gmail.com
- Update to version 2.18.2:
  + Really don't crash if we get a children-changed event with a
    non-existent child (bgo#755951).
  + Fixed crash during removal of last application in registryd
    (bgo#756513).
* Wed Oct 28 2015 mgorse@suse.com
- Disable xevie when configuring (boo#952011).
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 2.18.1:
  + Don't crash if we get a children-changed event with a
    non-existent child (bgo#755951).
  + atspi_hyperlink_get_index_range: don't return random values if
    the call fails (bgo#755727).
  + Fixed some atspi_text_ functions (bgo#755731).
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 2.18.0:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 2.17.90:
  + Modified the cache API to specify an object's index and child
    count rather than its children. This eliminates the need for
    the application to enumerate its children, improving
    performance in some places with large lists (bgo#650090).
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 2.17.1:
  + Functions shouldn't try to return values (bgo#749330).
  + Fix atspi_table_cell_get_position.
* Tue Mar 24 2015 zaitor@opensuse.org
- Update to version 2.16.0:
  + Fix GTK-Doc comment blocks.
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 2.15.90:
  + Deprecate atspi_text_get_text_{before,at,after}_offset()
    (bgo#697969).
  + Add roles for fractions, roots, subscripts, and superscripts
    (bgo#743403).
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 2.15.4:
  + Add names to every timeout (bgo#710644).
  + Remove accessibility.conf from EXTRA_DIST (bgo#742987).
  + Add ATSPI_STATE_READONLY (bgo#690004).
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 2.15.3:
  + Replace deprecated "Rename to" gtk-doc tag.
  + Fix atspi_table_cell_get_column_span prototype.
* Fri Nov 28 2014 zaitor@opensuse.org
- Update to version 2.15.2:
  + Make the documentation of ATSPI's STATE_ACTIVE consistent with
    that of ATK's (bgo#740274).
  + Add ATSPI_ROLE_STATIC and update documentation for
    ATSPI_ROLE_TEXT (bgo#740340).
  + gi-annotations: get_relation_set returns a array of
    AtspiRelation.
* Tue Nov 18 2014 zaitor@opensuse.org
- Update to version 2.15.1:
  + Fix some issues with the accessibility bus configuration
    (bgo#722738).
  + Documentation for AtspiTableCell is now built.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 2.14.1:
  + Docs: add AtspiTableCell.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 2.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 2.13.92:
  + Fix alignment checks when cross-compiling (bgo#736653).
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 2.13.90:
  + Fix crash when testing interfaces with collections
    (bgo#734805).
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 2.13.4:
  + Ensure that we register with the session manager only once
    (bgo#728934).
  + Fix ucs2keysym prototype (bgo#730897).
  + introspection: add some missing Returns: (nullable)
    annotations.
  + Fix various memory leaks.
* Fri May 30 2014 zaitor@opensuse.org
- Update to version 2.13.1:
  + Add GError setter in atspi_accessible_get_process_id function.
  + registryd: Wait for gnome-session before registering if it is
    not running yet (bgo#728934).
- Drop at-spi2-register-on-session-running.patch and
  at-spi2-core-cancel-logout.patch, fixed upstream.
* Fri May 30 2014 dliang@suse.com
- Add at-spi2-core-cancel-logout.patch (bnc#876680)
  gnome-session emit SessionRunning after turn back from
    QueryEndSession
* Tue May  6 2014 dliang@suse.com
- Add at-spi2-register-on-session-running.patch
  register the client when session manager is running. (bnc#873541)
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 2.12.0:
  + Stable release, no changes since 2.11.92.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 2.11.92:
  + Fix a crash with MediaElch and Onboard (bgo#726243).
  + Updated translations.
* Mon Mar 17 2014 mgorse@suse.com
- Add at-spi2-core-null-event-source.patch -- avoid crashing if
  an event's source is set to NULL (bgo#726243).
* Tue Mar  4 2014 zaitor@opensuse.org
- Update to version 2.11.91:
  + Improve compatibility with at-spi2-registryd <= 3.10.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 2.11.90:
  + bus-launcher: Do not use g_setenv when initializing the bus
    (bgo#724070).
  + Fix a critical when processing deferred messages (bgo#724292).
  + Add AtspitableCell, tracking the new atk interface.
* Tue Feb  4 2014 dimstar@opensuse.org
- Update to version 2.11.5:
  + Add atspi_event_listener_register_full, and cache data
    requested by it for the duration of the event callback
    (bgo#708695).
  + Fix a crash when atspi_accessible_get_process_id is called for
    an application that is no longer present.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 2.11.3:
  + Fix atspi_text_get_bounded_ranges.
  + bgo#719508: document: add support to current page and page
    count.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 2.11.2:
  + Add new roles and states to track atk (bgo#710464, bgo#712608,
    bgo#712609).
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 2.11.1:
  + Hopefully fix a rare crash when starting at-spi2-registryd
    (bgo#710689).
  + Fix atspi_component_contains (bgo#710730).
  + Fix some compiler warnings and build issues.
* Tue Nov 12 2013 dimstar@opensuse.org
- Update to version 2.10.2 (bnc#849913):
  + Fix atspi_component_contains (bgo#710730).
  + Hopefully fix a crash when unable to register with the session
    manager (bgo#710689).
* Mon Oct 14 2013 dimstar@opensuse.org
- Update to version 2.10.1:
  + Fix a leak introduced in 2.9.92 that adversely affected
    performance (bgo#709625).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 2.10.0:
  + No changes since 2.9.92.
* Mon Sep 16 2013 zaitor@opensuse.org
- Update to version 2.9.92:
  + Fix multiple deadlocks with keystroke listeners (bgo#707218).
* Mon Sep  2 2013 zaitor@opensuse.org
- Update to version 2.9.91:
  + Fix a performance issue when running for a long time without a
    main loop, such as with a dogtail script (bgo#701145).
  + Remove an unneeded unref that was causing a warning
    (bgo#706893).
  + Skip some functions that were not introspectable (bgo#707010).
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 2.9.90:
  + Separate out X-dependent functionality, allow building without
    X11 (bgo#682199, bgo#701378).
  + Add atspi_text_get_string_at_offset, and deprecate
    atspi_text_get_text_at_offset.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 2.9.5:
  + Fix possible memory leak when D-Bus calls time out.
  + Fix a memory leak in atspi_accessible_get_role_name that was
    introduced earlier in the 2.9 cycle with the enum refactor.
  + A couple of functions not intended for introspection are now
    marked as skip.
* Mon Jul  8 2013 dimstar@opensuse.org
- Update to version 2.9.4:
  + Add atspi_set_main_context (mainly for use by at-spi2-atk).
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 2.9.3:
  + Add atspi_is_initialized (bgo#681276).
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 2.9.2:
  + Fix D-Bus introspection for GetActions.
  + Use glib-mkenums to generate enum types, and use these
    generated types for role and state names, rather than static
    tables.
  + nnotate filter in atspi_register_device_event_listener with
    allow-none (bgo#700237).
  + Rename various functions to avoid name collisions (bgo#700243).
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 2.8.0:
  + Updated translations.
* Mon Mar  4 2013 zaitor@opensuse.org
- Update to version 2.7.91:
  + Add atspi_accessible_get_object_locale (bgo#694368).
  + Start the bus launcher in the initialization phase
    (bgo#694984).
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 2.7.90:
  + Removed a debug print that was accidentally included in 2.7.5.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 2.7.5:
  + Add ATSPI_ROLE_LEVEL_BAR to correspond to the new atk role.
  + Fix various compiler warnings.
- Drop at-spi2-core-brp-fixes.patch: fixed upstream.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 2.7.4.1:
  + Fix some ref count leaks.
  + Some functions that return accessibles now propagate errors.
- Add at-spi2-core-brp-fixes.patch: Fix brp errors (no return in
  non-void function and void return).
* Wed Dec 26 2012 zaitor@opensuse.org
- Update to version 2.7.3:
  + Atspi_accessible_get_index_in_parent no longer returns -1 if
    the object's parent is not cached (bgo#688057).
  + Re-register keystroke listeners if the registry goes away and
    then returns.
  + Fix atspi_device_listener_new_simple.
  + Fix some compiler warnings.
  + Build: use gobject-introspection's Makefile instead of rolling
    our own.
  + Fix a crash when parsing events without detail when there is a
    listener for the event that names a specific detail value.
  + Fix crash when removing hung processes.
  + Fix deregistering of applications.
  + A few documentation fixes.
- Changes from version 2.7.2:
  + Only call an event listener once per event, even if the
    listener registered for both the event and a superset of the
    event.
  + Don't distribute dbind-config.h (bgo#688083).
  + Fix gtk-doc for Atspi-Registry (bgo#688224).
  + Some introspection fixes to make vapigen happy (bgo#688223).
  + Fixed a crash handling DeregisterKeystrokeListener.
- Changes from version 2.7.1:
  + Update the cache in response to role change notifications
    (bgo#685469).
  + Don't output a warning when a p2p connection isn't available.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 2.6.3:
  + Fix several crashes.
  + Fix atspi_accessible_get_index_in_parent when the parent is not
    cached.
  + Fix deregistering of applications.
  + Fix some compiler warnings.
* Mon Dec  3 2012 dimstar@opensuse.org
- Add baselibs.conf in order to provide libatspi0-32bit and
  at-spi2-core-devel-32bit. The library is needed by
  libatk-bridge-2_0-0-32bit.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 2.6.2:
  + Don't output a warning when a p2p connection isn't available.
  + Don't distribute dbind-config.h (bgo#688083).
* Wed Oct 17 2012 dimstar@opensuse.org
- Update to version 2.6.1:
  + Update cache in response to role change notifications
    (bgo#685469).
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 2.6.0:
  + Stable release - No changes compared to 2.5.92.
* Tue Sep 18 2012 zaitor@opensuse.org
- Update to version 2.5.92:
  + Fix some annotations.
  + Exit, rather than crash, when unable to open an X display
    (bgo#660407).
  + Fix various memory leaks (bgo#684033).
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 2.5.91:
  + Fix build with -fno-common.
  + Add glib-2.0 to requires in at-spi2.pc (bgo#682595).
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 2.5.5:
  + Add atspi_action_get_localized_name (bgo#680598).
  + Allow building from out of source directory (bgo#680281).
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 2.5.4:
  + Fix a missing return value.
  + Fix a crash when unable to remove a match rule.
* Tue Jun 26 2012 dimstar@opensuse.org
- Update to version 2.5.3:
  + Fix a memory leak (bgo#678738).
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 2.5.2:
  + Fix a crash when a call to fetch a hyperlink times out.
  + Fix C++ compilation.
  + Remove a warning that was sometimes logged when a method call
    timed out.
  + Fix crash in atspi_deregister_keystroke_listener (fdo#50578)
* Thu May 17 2012 zaitor@opensuse.org
- Update to version 2.5.1:
  + Add atspi_set_timeout.
  + By default, disable method call timeouts until an application
    has been on the bus for 15 seconds. This behavior can be
    changed with a call to atspi_set_timeout.
  + Fix GError sent when receiving a reply of the wrong type.
* Tue May 15 2012 vuntz@opensuse.org
- Update to version 2.4.2:
  + Fix typo in atspi_document_get_attribute_value
  + Fix a potential crash when unsuccessfully querying for a
    hyperlink.
  + bgo#675004: object:state-changed:defunct events are emitted as
    object:state-change:defunct
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 2.4.1:
  + Fix a GError set when a method call returns a reply of the
    wrong type.
  + Do not time out method calls for the first 15 seconds that an
    application is on the bus (work-around for Orca setting an
    application's script as "default" after a timeout on a
    slow-starting application).
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 2.4.0:
  + Fix typo in at-spi-dbus-bus.desktop.in (bgo#605662).
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 2.3.92:
  + Some changes to try to prevent at-spi2-registryd from
    incorrectly thinking that an AT is hung and passing keys meant
    for it to the application.
  + Fix crash fetching an error from a reply when retrieving a
    property.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 2.3.91:
  + Invalid states when receiving a focus event (bgo#663992).
  + Fix atspi_table_get_row_column_extents_at_index.
  + Expect a signed in tfor GetIndexInParent, per the spec.
  + Send key events to listeners assumed to be hung, but don't
    block.
  + Reduce the method call timeout slightly, so that it will be
    lower than the keystroke listener timeout.
  + Don't cache data for transient objects.
  + Enable caching on a call to atspi_accessible_set_cache_mask,
    even if atspi_event_main() hasn't been called.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 2.3.90:
  + At-spi-bus-launcher now emits PropertiesChanged signals from
    the correct interface.
  + If a keystroke listener does not respond, disable it until it
    responds. This prevents the desktop from locking up if an AT
    hangs or is suspended and has a keyboard listener registered.
  + Fix a warning when a NULL object is returned as the detail of
    an event.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 2.3.5:
  + Add some type checking on method replies; this should prevent
    crashes if an application-side AT-SPI implementor returns
    something unexpected.
  + Call g_settings_sync after updating toolkit-accessibility.
  + Add ScreenReaderEnabled D-Bus property as a proxy for the
    GSettings key.
  + bgo#668334: Set correct end offset in
    atspi_text_get_attributes.
  + bgo#669344: Don't use "restrict" as a variable name, since it
    can be a keyword.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 2.3.4:
  + Add some dbus message signature checks.
  + Fix a crash if a device listener incorrectly returns a
    non-bool.
  + bgo#666870: Keystroke listeners do not work unless an event
    listener is also registered [also needs updated at-spi2-atk]
  + bgo#667254: Some atspi-selection_* functions were broken.
  + When a call times out, ping the connection and avoid making
    subsequent calls until the ping is answered.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 2.3.3:
  + Handle event detail suffixes (such as :system).
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Rewrite description of libatspi0 subpackage.
- Split typelib file into typelib-1_0-Atspi-2_0 subpackage.
- Add typelib-1_0-Atspi-2_0 Requires to devel subpackage.
* Tue Nov 22 2011 vuntz@opensuse.org
- Update to version 2.3.2:
  + Some documentation improvements.
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.3.1:
  + Fix return type of org.a11y.Bus.IsEnabled property
  + Declare void functions as such
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 2.2.1:
  + Fix org.a11y.Bus.Enabled property to set its initial state from
    the GSettings key, if available and an initial property is not
    given on the command line.
  + bgo#660947: Gracefully exit when already running, rather than
    triggering a SIGABRT.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 2.2.0:
  + Minor bug fix.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 2.1.92:
  + Fixed a crash when handling event listeners.
  + Add some defensive checks to prevent problems with defunct
    objects.
  + Fix some missing return statements.
  + Some fixes related to deregistering event listeners.
  + bgo#659088: Correctly define ATSPI_MODIFIER_NUMLOCK.
  + bgo#657051: Fix a build error on Solaris.
- Drop at-spi2-core-missing-return.patch: fixed upstream.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 2.1.91:
  + Fixed a crash when deregistering event listeners.
  + Made DBus IsEnabled property readwrite.
- Add at-spi2-core-missing-return.patch: add missing returns to fix
  build.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.1.90:
  + Fixed a memory leak on DBus errors.
  + Added org.a11y.Status.IsEnabled (currently a read-only
    property) to the bus launcher.
  + Clean up device listeners from disconnected applications.
  + bgo#656004: atspi_accessible_get_relation_set returns a GArray
    again.
  + bgo#657585: Do not crash when the bus launcher is unable to
    open the X display.
  + Numerous documentation fixes.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 2.1.5:
  + Propertly free DBus error in atspi_accessible_get_process_id.
  + Clean up names of some private functions.
  + Move DBus interface name constants into atspi-constants.h and
    make public.
  + Remove support for relocated CORBA.
  + bgo#655127: Python crash for atspi_accessible_get_relation_set.
* Tue Jul 26 2011 vuntz@opensuse.org
- Update to version 2.1.4:
  + Some API changes to device and event listeners for
    compatibility with Javascript.
  + bgo#654314: make role names consistent with atk.
  + bgo#654921: Run within Unity.
  + Added some new roles.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 2.1.3:
  + Use stored values for AT-SPI role names where possible.
  + bgo#652596: Use DBus property to set value.
  + Set error for some DBus errors where this was not being done.
  + Add atspi_accessible_get_process_id (as a short-cut to help
    debugging).
  + Fix failure to update cache in response to children-changed
    events in some cases.
  + Fix gtk-doc build cflags/libraries.
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 2.1.2:
  + Merge changes from 2.0.2.
  + Cache application-wide toolkit name and version.
  + Allow caching of attributes, but not enabling by default, as
    there is no event yet (bgo#649771).
  + Make deferred_messages a GQueue rather than a GList for
    performance reasons.
  + Fix accessibility bus breakage when a user runs an
    administrative app.
* Mon May 30 2011 fcrozat@novell.com
- Update to version 2.0.2:
  + bgo#648942: fixed a seg fault in at-spi-bus-launcher when
    ending a session.
  + Fixed a possible crash when an application is short-lived.
  + Fixed memory leaks in
    atspi_accessible_get_toolkit_(name|version).
  + AT-SPI will now call g_error if it is unable to find the
    accessibility bus. This results in aborting but with a somewhat
    less cryptic error than before.
  + Fix atspi_table_get_caption|summary.
  + Fix introspection for atspi_table_get_row_column_at_index.
  + Copy match rule attributes, rather than just ref counting the
    hash, for compatibility with pygi.
  + Rework atspi_accessible_set_cache_mask to make it usable.
  + Fix a crash that might happen if a method call times out.
  + Disable caching if atspi_event_main has not been called to run
    the main loop.
  + Fix atspi_accessible_get_toolkit_version.
  + Add atspi_accessible_get_atspi_version to fetch the version of
    the AT-SPI specification provided by an application.
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 2.0.1:
  + Fix a memory leak when sending events.
  + bgo#648059: get_application should return something
    w/ROLE_APPLICATION.
  + bgo#648130: event host_application should return NULL for the
    desktop.
  + Added atspi_accessible_get_id to retrieve the id of an
    application.
  + Remove doc about non-existent ATSPI_KEYSET_ALL_KEYS.
  + Build fixes (bgo#648013, bgo#648014).
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 2.0.0:
  + bgo#646403: Use correct signature in at-spi2-registryd for
    EndSessionResponse.
  + Remove a Makefile reference to dbus-glib.
- Remove BuildRequires on pkgconfig(dbus-glib-1).
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 1.91.93:
  + clear AT_SPI_BUS property on launcher exit, so that early login
    processes from a new session don't pick up the stale address.
  + remove dbus-glib includes as they are no longer needed.
- Drop patch clear-x-property.patch: fixed upstream
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 1.91.92:
  + Fixed atspi_table_get_column_header and
    atspi_value_set_current_value.
  + Removed dbus-glib dependency; libatspi now includes a copy of
    dbus-gmain.c modified to fix a crash (fdo#35115).  Session
    management code has been ported to gdbus.
  + Fixed a crash when deregistering a keystroke listener.
  + Reworked accessibility bus management (bgo#644851).
  + Fixed a possible sign issue with state sets.
- Changes from version 1.91.91:
  + Changed device event IPC to use uint32 for hw_code and
    modifiers, to be more consistent with the rest of the API.
  + GetNSelections has an out parameter, not an in.
  + bgo#643384: atspi_register_keystroke_listener() should take a
    bitmask, not AtspiKeyListenerSyncType.
  + Avoid setting enum values to 0x80000000, to prevent a pygi
    exception.
  + bgo#643454: Kill the accessibility bus daemon with the GNOME
    session
  + bgo#643110: Do not allow all users to connect to the
    accessibility bus.
- Replace devel build requires with their pkgconfig() counterparts:
  dbus-1-glib-devel => dbus-1 and dbus-glib-1.
- Add clear-x-property.patch: clear X property for accessibility
  bus, ensuring gdm bus doesn't leak to user session.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 1.91.90:
  + bgo#641164: Fixed several build errors.
  + Fixed some memory leaks and possible crashes.
  + Fixed atspi_selection_get_selected_child and
    atspi_selection_get_n_selected_children.
  + Fixed wrong introspection information in some places.
  + bgo#641869: Removed the --enable-relocate option.
  + Avoid returning uninitialized data on error for some methods.
  + Use the GSettings rather than GConf key to test that
    accessibility is enabled.
  + Change some enums from 16-bit to 32-bit to match spec.
- Changes from version 1.91.6:
  + Build fixes
  + Added a method to check whether an object implements the
    Hyperlink interface.
  + Fixed a crash in atspi_image_get_image_description.
  + Fixed atspi_editable_text_set_text_contents.
  + More error-handling fixes.
  + Fixed a crash in atspi_event_listener_register_from-callback.
  + Method calls now time out after 1 second.
  + Added setters for component extents/size/position.
  + Added atspi-accessible_set_cache_mask.
  + Updated translations.
- Changes from version 1.91.5:
  + Fixed several memory leaks.
  + Fixed some text methods, methods that return points or
    rectangles, image locale and description,
    atspi-accessible_get_description, and some table methods.
  + Added a trailing colon for focus events.
  + Set the error parameter for dbus errors rather than
    displaying a warning.
  + Fixed the keystroke listener deregister method.
  + The cache is now updated before raising an event, not after,
    so that event handlers that query for cached values will see
    the updated data.
  + The registry daemon now returns an error when a caller
    requests a property that the desktop does not support.
  + Added disposal of objects, and fixed several associated bugs.
  + Added i18n.
  + Fixed mouse events.
  + Libatspi's documentation is now compiled with gtk-doc.
  + Fixed building from a separate build directory.
- Changes from version 1.91.4:
  + Use peer-to-peer connections when available.
  + Fix uninitialized variable in get_index_in_parent.
  + Add timeout, and support inspecting our own app.
  + Add get_interfaces, and fetch interface and state set over the
    wire if needed.
  + Avoid adding data for an accessible twice if it is referenced
    prior to an AddAccessible signal being received.
  + Fix copying of any_data for an event.
  + at-spi-registryd returns ChildCount as a variant, per the DBus
    spec.
  + Hypertext, hyperlink, and table fixes.
  + Several cache-related fixes.
  + Change some error return values to match AT-SPI-CORBA behavior.
  + Some attribute-related fixes.
  + Renamed 'text' to 'content' in AtspiTextRange to match original
    IDL.
- Changes from version 1.91.3:
  + Added a C-based AT-side binding (libatspi) which can be used in
    conjunction with GObject introspection to generate bindings for
    other languages.
- Changes from version 1.91.2:
  + The desktop object now returns ROLE_DESKTOP_FRAME rather than
    ROLE_UNKNOWN.
- Changes from version 1.91.0:
  + --disable-relocate is the default again.
- Create new subpackages libatspi0 and at-sp2-core-dbus-devel
- Add intltool BuildRequires.
- Do not call ldconfig in %%post/%%postun of main package since there
  is no library there.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add call to ./autogen.sh.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.4.1:
  + Have the desktop object return ROLE_DESKTOP_FRAME.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.4.0:
  + Version bump to stable 0.4.0, without any change.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 0.3.92:
  + Do not start accessibility bus if at-spi-corba is enabled.
* Tue Aug 31 2010 vuntz@opensuse.org
- Update to version 0.3.91:
  + Enabled the accessibility bus, so apps should be accessible,
    for instance, if an application becomes setuid root.
  + Several build fixes.
  + Default to --enable-relocate for now.
- Drop at-spi2-core-dbus-path.patch: this is not needed anymore
  since the path to the dbus daemon is not in the config file
  anymore.
- Uncomment call to %%suse_update_desktop_file for
  at-spi-dbus-bus.desktop.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 0.3.90:
  + fdo#29427: Registering for mouse:abs now works.
  + Add methods/signals to allow an application to track the events
    that are being listened to to avoid unnecessarily emitting
    signals.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.3.4:
  + Added GetChildren to the spec.
* Fri Jun  4 2010 sshaw@decriptor.com
- Update to version 0.3.3:
  + Add return values to some functions that were missing them.
  + Make DeviceEventListener notifiers reentrant so that an
    application can query the desktop object while processing a
    device event.
  + Fix for fdo#28300: fails to link with pedantic linkers.
  + Fix crash if GetChildAtIndex is called with an invalid index.
- Changes from version 0.3.2:
  + Make sure that disconnecting applications send their root path
    in the remove applications signal. This was causing
    applications to not be removed from the desktop properly.
- Changes from version 0.3.1:
  + Set an application's Id when registering it.
  + Disabled relocation by default.
- Drop at-spi2-core-non_void.patch: fixed upstream.
- This fixes a crash in firefox when at-spi2 is used, see
  bnc#611149.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 0.1.8:
  + Quit if at-spi-dbus is disabled
  + Call g_type_init()
* Mon Mar  1 2010 ro@suse.de
- fix warning: no return statement in function returning non-void
  in registry.c to fix build
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.1.7:
  + Completely re-work the protocol definitions.
  + Make the desktop object and deviceeventcontroller
    introspectable.
  + Add the XML files to the distribution.
  + Modify the interface name from org.freedesktop.atspi to
    org.a11y.atspi.
* Fri Feb 12 2010 vuntz@opensuse.org
- Update to version 0.1.6:
  + Fix interface name
  + Tweak the at-spi-dbus-bus.desktop file to add @bindir@ and
    X-GNOME-Autostart-Phase
  + Do not run at-spi-dbus-bus at initialization phase
  + Make the registry implement the accessible interface and add
  + Fix marshalling issues with the desktop Component, Accessible
  + Fix wrong bus name being sent whan children are removed.
  + Update Cache interface in the spec, and rename from Tree
  + Return the address of the registry from the socket/Embed method
  + Return Parent as a variant
  + Fix mouse click events. They were not being sent with their
    application.
  + Move the application argument to the end of the event structure
  + Remove the bus from the build/install for now
  + Remove the bus makefile from configure to fix distcheck errors.
- Do not apply at-spi2-core-dbus-path.patch anymore, but keep it:
  the part that is patched is temporarily removed from the
  tarballs, but it will come back later.
- For the same reason, comment out call to
  suse_update_desktop_file.
* Fri Jan 15 2010 vuntz@opensuse.org
- Update to version 0.1.5:
  + For the full list of changes, see
    http://git.gnome.org/cgit/at-spi2-core/log/?id=AT_SPI2_CORE_0_1_5
  + Remove GDK dependency from registry daemon
  + Fix build errors
  + Fix mouse:button events
- Change gtk2-devel BuildRequires to glib2-devel and
  xorg-x11-devel.
* Tue Dec 22 2009 vuntz@opensuse.org
- Update to version 0.1.4:
  + For the full list of changes, see
    http://git.gnome.org/cgit/at-spi2-core/log/?id=AT_SPI2_CORE_0_1_4
  + Use the new 'Accessibility' bus if the bus address is available
    on the X property AT_SPI_BUS.
  + Add command line option to enable interaction with the gnome
    session manager.
  + Add the configure file for the (non-secure) accessibility bus.
  + Use datarootdir for placing XML files so that the are in a
    shared directory not under the name of this module but
    'at-spi2'.
  + Make sure the d-bus bus configuration is included in the
    distribution.
  + Add a configure variable for the location of the dbus-daemon in
    the at-spi-dbus-bus script.
- Pass --with-dbus-daemondir to configure.
- Add at-spi2-core-dbus-path.patch to use the right path for a dbus
  helper.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 0.1.3:
  + For a list of changes, see
    http://git.gnome.org/cgit/at-spi2-core/log/?id=AT_SPI2_CORE_0_1_3
- Pass libexecdir/at-spi2 for libexecdir to configure.
- Remove devel package: there's no library anymore for this
  package.
- Obsolete devel package, without providing it (that would be
  wrong). Add a rpmlintrc file to make rpmlint happy for this.
- Remove conflict with at-spi: the files are now different and will
  not clash.
* Fri Aug 14 2009 sshaw@decriptor.com
- Update to version 0.1.1:
  + Replace use of dbind_emit_signal with direct libdbus call in
    application cache update. fdo#23029
  + Fix problem with signature assignment and iter initialization
    in dbind signal sending.
  + Modify the incorrect use of dbind_emit_signal_va. Check for
    NULL args in dbind_marshall_any. fdo#23027
  + Remove *.pc files from source tarballs.
  + Remove python check from configure.ac. Python is not needed for
    at-spi2-core.
  + Link DRoute against D-Bus GLib.
- Remove python BuildRequires.
* Fri Aug 14 2009 vuntz@novell.com
- Clean up packaging a bit.
* Thu Aug 13 2009 sshaw@decriptor.com
- Initial packaging of at-spi2-core (0.1.0)
